@@ -270,11 +270,10 @@ class WordPressManager {
         // Save site information to database
         $stmt = $this->db->prepare("
             INSERT INTO wordpress_sites 
-            (user, domain, container_name, admin_email, admin_username, wp_version, preferred_backup_target_id) 
-            VALUES (?, ?, ?, ?, ?, ?, ?)
+            (user, domain, container_name, admin_email, admin_username, preferred_backup_target_id) 
+            VALUES (?, ?, ?, ?, ?, ?)
         ");
         
-        $version = $this->getWordPressVersion($data['container'], $data['user'], $path);
         // Handle backup target ID - convert empty string to null
         $backupTargetId = null;
         if (!empty($data['backup_target_id']) && is_numeric($data['backup_target_id'])) {
@@ -287,7 +286,6 @@ class WordPressManager {
             $data['container'],
             $data['admin_email'],
             $data['admin_username'],
-            $version,
             $backupTargetId
         ]);
         
@@ -511,13 +509,9 @@ class WordPressManager {
             // Update database if needed
             $result = $this->execWpCli($site['container_name'], $site['user'], "wp core update-db");
             
-            // Get new version
+            // Get new version for response (don't store in DB - get dynamically when needed)
             $newVersion = $this->getWordPressVersion($site['container_name'], $site['user']);
             
-            // Update site record
-            $stmt = $this->db->prepare("UPDATE wordpress_sites SET wp_version = ? WHERE id = ?");
-            $stmt->execute([$newVersion, $siteId]);
-            
             // Record success
             $this->recordUpdateComplete($updateId, $newVersion);
             
@@ -673,8 +667,8 @@ Options -Indexes
         // Create WordPress site record
         $stmt = $this->db->prepare("
             INSERT INTO wordpress_sites 
-            (user, domain, container_name, site_path, admin_email, admin_username, wp_version, database_name, preferred_backup_target_id, status, created_at)
-            VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, 'active', NOW())
+            (user, domain, container_name, site_path, admin_email, admin_username, database_name, preferred_backup_target_id, status, created_at)
+            VALUES (?, ?, ?, ?, ?, ?, ?, ?, 'active', NOW())
         ");
         
         $stmt->execute([
@@ -684,7 +678,6 @@ Options -Indexes
             $sitePath,
             $wpInfo['admin_email'] ?? '',
             $wpInfo['admin_user'] ?? '',
-            $wpInfo['version'] ?? '',
             $dbInfo['name'] ?? '',
             $backupTargetId
         ]);
@@ -1087,9 +1080,9 @@ Options -Indexes
         // Create staging site record
         $stmt = $this->db->prepare("
             INSERT INTO wordpress_sites 
-            (user, domain, container_name, site_path, wp_version, is_staging, parent_site_id, 
+            (user, domain, container_name, site_path, is_staging, parent_site_id, 
              admin_email, admin_username) 
-            VALUES (?, ?, ?, ?, ?, 1, ?, ?, ?)
+            VALUES (?, ?, ?, ?, 1, ?, ?, ?)
         ");
         
         $stmt->execute([
@@ -1097,7 +1090,6 @@ Options -Indexes
             $stagingDomain,
             $stagingContainer,
             $stagingPath,
-            $site['wp_version'],
             $siteId,
             $site['admin_email'],
             $site['admin_username']
